{% extends "!layout.html" %}

{% block rootrellink %}
{{ toctree() }}
{% endblock %}


{% block relbar1 %}

<div style="background-color: white; text-align: left; padding: 10px 10px 15px 15px">
  <a href="{{ pathto('index') }}"><img src="{{
pathto(" _static/logo_pydoe3.png", 1) }}" border="0" alt="ad" /></a>
</div>
{{ super() }}
{% endblock %}


{#############################################################################}
{# Sidebar customization #)

{# put the sidebar before the body #}
{% block sidebar1 %}

{%- macro sidebar() %}
{%- if not embedded %}{% if not theme_nosidebar|tobool %}
<div class="sphinxsidebar">
  <div class="sphinxsidebarwrapper">
    {%- block sidebarlogo %}
    {%- if logo %}
    <p class="logo"><a href="{{ pathto(master_doc) }}">
        <img class="logo" src="{{ pathto('_static/' + logo, 1) }}" alt="Logo" />
      </a></p>
    {%- endif %}
    {%- endblock %}
    {%- block sidebartoc %}
    {%- block sidebarglobaltoc %}
    <h3>{{ _('Table of contents') }}</h3>
    {{ toctree() }}
    {%- endblock %}
    {%- endblock %}
    {%- block sidebarrel %}
    {%- endblock %}
    {%- block sidebarsourcelink %}
    {%- if show_source and has_source and sourcename %}
    <h3>{{ _('This Page') }}</h3>
    <ul class="this-page-menu">
      <li><a href="{{ pathto('_sources/' + sourcename, true)|e }}" rel="nofollow">{{ _('Show Source') }}</a></li>
    </ul>
    {%- endif %}
    {%- endblock %}
    {%- if customsidebar %}
    {% include customsidebar %}
    {%- endif %}
    {%- if display_toc %}
    <h3>{{ _('Section contents') }}</h3>
    {{ toc }}
    {%- endif %}
    {%- block sidebarsearch %}
    {%- if pagename != "search" %}
    <div id="searchbox" style="display: none">
      <h3>{{ _('Quick search') }}</h3>
      <form class="search" action="{{ pathto('search') }}" method="get">
        <input type="text" name="q" size="18" />
        <input type="submit" value="{{ _('Go') }}" />
        <input type="hidden" name="check_keywords" value="yes" />
        <input type="hidden" name="area" value="default" />
      </form>
      <p class="searchtip" style="font-size: 90%">
        {{ _('Search the documentation.') }}
      </p>
    </div>
    <script type="text/javascript">$('#searchbox').show(0);</script>
    {%- endif %}
    {%- endblock %}
    {%- block copyright %}
    <h3>Documentation license</h3>
    <a rel="license" href="http://creativecommons.org/licenses/by-nc-nd/3.0/"><img alt="Creative Commons License"
        style="border-width:0" src="http://i.creativecommons.org/l/by-nc-nd/3.0/88x31.png" /></a>
    {%- endblock %}
  </div>
</div>
{%- endif %}{% endif %}
{%- endmacro %}

{{ sidebar() }}{% endblock %}


{% block sidebar2 %}{% endblock %}